@@ -1,11 +1,11 @@
 from django.core.exceptions import ValidationError
 from django.db import models
-from django.db.backends.postgresql_psycopg2.base import DatabaseWrapper
-from django.utils.six import with_metaclass, text_type
+
 from ipaddress import ip_interface, ip_network
 from netaddr import EUI
 from netaddr.core import AddrFormatError
 
+from netfields.compat import DatabaseWrapper, with_metaclass, text_type
 from netfields.forms import InetAddressFormField, CidrAddressFormField, MACAddressFormField
 from netfields.mac import mac_unix_common
 from netfields.psycopg2_types import Inet, Macaddr
@@ -57,12 +57,17 @@ class _NetAddressField(models.Field):
             raise ValidationError(e)
 
     def get_prep_lookup(self, lookup_type, value):
-
+        if hasattr(value, '_prepare'):
+            try:
+                # Django 1.8
+                return value._prepare()
+            except TypeError:
+                # Django 1.9
+                return value._prepare(self)
         if (lookup_type in NET_OPERATORS and
                     NET_OPERATORS[lookup_type] not in NET_TEXT_OPERATORS):
-            if (lookup_type.startswith('net_contained') or
+            if (lookup_type.startswith('net_') or
                     lookup_type.endswith('prefixlen')) and value is not None:
-                # Argument will be CIDR
                 return str(value)
             return self.get_prep_value(value)
 
@@ -95,7 +100,12 @@ class _NetAddressField(models.Field):
 
         if (lookup_type in NET_OPERATORS and
                     NET_OPERATORS[lookup_type] not in NET_TEXT_OPERATORS):
-            return [value] if prepared else [self.get_prep_value(value)]
+            if prepared:
+                return [value]
+            if (lookup_type.startswith('net_') or
+                    lookup_type.endswith('prefixlen')) and value is not None:
+                return str(value)
+            return [self.get_prep_value(value)]
 
         return super(_NetAddressField, self).get_db_prep_lookup(
             lookup_type, value, connection=connection, prepared=prepared)
