@@ -2,9 +2,9 @@ from ipaddress import ip_interface, ip_network, _IPAddressBase, _BaseNetwork
 from netaddr import EUI, AddrFormatError
 
 from django import forms
-from django.utils.six import text_type
 from django.core.exceptions import ValidationError
 
+from netfields.compat import text_type
 from netfields.mac import mac_unix_common
 
 
