@@ -60,6 +60,8 @@ class IRegex(NetFieldDecoratorMixin, IRegex):
 
 class NetworkLookup(object):
     def get_prep_lookup(self):
+        if hasattr(self.rhs, 'resolve_expression'):
+            return self.rhs
         if isinstance(self.rhs, ipaddress._BaseNetwork):
             return str(self.rhs)
         return str(ipaddress.ip_network(self.rhs))
@@ -67,6 +69,8 @@ class NetworkLookup(object):
 
 class AddressLookup(object):
     def get_prep_lookup(self):
+        if hasattr(self.rhs, 'resolve_expression'):
+            return self.rhs
         if isinstance(self.rhs, ipaddress._BaseAddress):
             return str(self.rhs)
         return str(ipaddress.ip_interface(self.rhs))
